(function (blocks, editor, components, i18n, element) {

  var el = element.createElement
  var registerBlockType = blocks.registerBlockType
  var BlockControls = editor.BlockControls
  var InspectorControls = editor.InspectorControls
  var TextControl = components.TextControl
  var SelectControl = components.SelectControl
  var CheckboxControl = components.CheckboxControl
  var ServerSideRender = components.ServerSideRender

  // custom block icon
  const iconEl = el('svg', { width: 20, height: 20 },
    el('path', { d: "M12.5,12H12v-0.5c0-0.3-0.2-0.5-0.5-0.5H11V6h1l1-2c-1,0.1-2,0.1-3,0C9.2,3.4,8.6,2.8,8,2V1.5C8,1.2,7.8,1,7.5,1 S7,1.2,7,1.5V2C6.4,2.8,5.8,3.4,5,4C4,4.1,3,4.1,2,4l1,2h1v5c0,0-0.5,0-0.5,0C3.2,11,3,11.2,3,11.5V12H2.5C2.2,12,2,12.2,2,12.5V13 h11v-0.5C13,12.2,12.8,12,12.5,12z M7,11H5V6h2V11z M10,11H8V6h2V11z" })
  );

  const { __ } = i18n;

  // register social login custom block
  registerBlockType('wpweb/woo-collections-block', {
    title: 'WooCommerce Collections',
    description: __('Display WooCommerce Collections shortcode as block using the Gutenberg editor.'),
    icon: 'networking',
    category: 'widgets',
    attributes: { // Necessary for saving block content.
      /* Add to collection */
      woo_cl_shortcodes: {
        type: 'string',
        default: ''
      },
      woo_cl_add_to_collection_id: {
        type: 'text',
        default: ''
      },
      woo_cl_add_to_collection_text: {
        type: 'text',
        default: __('Add to Collection'),
      },
      woo_cl_add_to_collection_type: {
        type: 'string',
        default: __('default')
      },
      cl_add_to_collection_link_icon: {
        type: 'string',
        default: __('')
      },

      /* Featured collection */
      woo_cl_featured_colls_title: {
        type: 'text',
        default: __('Featured Collections')
      },
      woo_cl_no_of_coll: {
        type: 'text',
        default: __('10')
      },
      woo_cl_show_private: {
        default: false
      },

      /* My Collections */
      woo_cl_my_colls_title: {
        type: 'text',
        default: __('My Collections')
      },
      woo_cl_show_all_colls_count: {
        default: true
      },
      woo_cl_show_all_colls_link: {
        default: true
      },
    },

    edit: function (props) {
      
      var attributes = props.attributes
      var woo_cl_shortcodes = props.attributes.woo_cl_shortcodes

      /* Add to collection */
      var woo_cl_add_to_collection_id = props.attributes.woo_cl_add_to_collection_id
      var woo_cl_add_to_collection_text = props.attributes.woo_cl_add_to_collection_text
      var woo_cl_add_to_collection_type = props.attributes.woo_cl_add_to_collection_type
      var cl_add_to_collection_link_icon = props.attributes.cl_add_to_collection_link_icon

      /* Featured collection */
      var woo_cl_featured_colls_title = props.attributes.woo_cl_featured_colls_title
      var woo_cl_no_of_coll = props.attributes.woo_cl_no_of_coll
      var woo_cl_show_private = props.attributes.woo_cl_show_private

      /* My Collections */
      var woo_cl_my_colls_title = props.attributes.woo_cl_my_colls_title
      var woo_cl_show_all_colls_count = props.attributes.woo_cl_show_all_colls_count
      var woo_cl_show_all_colls_link = props.attributes.woo_cl_show_all_colls_link

      if (woo_cl_shortcodes == "" || woo_cl_shortcodes == "woo_cl_add_to_collection") {
        return [
          el(BlockControls, { key: 'controls' }, ),// Display controls when the block is clicked on.
          el(InspectorControls, { key: 'inspector' }, // Display the block options in the inspector panel.
            el(components.PanelBody, {
              title: i18n.__('WooCommerce Collections Settings'),
              className: 'wp-block-settings',
              initialOpen: true
            },
            // Select A Shortcode
            el(SelectControl, {
                label: i18n.__('Select A Shortcode'),
                help: i18n.__('Add A WooCommerce Collections Shortcode.'),
                value: woo_cl_shortcodes,
                options: [
                  { label: i18n.__('Add to Collection'), value: 'woo_cl_add_to_collection' },
                  { label: i18n.__('Featured Collections'), value: 'woo_cl_featured_collections' },
                  { label: i18n.__('My Collections'), value: 'woo_cl_my_collections' },
                ],
                onChange: function (response_woo_cl_shortcodes) {
                  props.setAttributes({ woo_cl_shortcodes: response_woo_cl_shortcodes })
                }
            }),

            // Product ID
            el(TextControl, {
                type: 'text',
                label: i18n.__('Product ID'),
                help: i18n.__('Here you can add product id for which you want to add to collection.'),
                value: woo_cl_add_to_collection_id,
                onChange: function (response_woo_cl_add_to_collection_id) {
                  props.setAttributes({ woo_cl_add_to_collection_id: response_woo_cl_add_to_collection_id })
                }
            }),
            el(TextControl, {
                type: 'text',
                label: i18n.__('Button Text'),
                help: i18n.__('Here you can give the Add to Collection button custom text. Default is: Add to Collection. Available template tag is : {no_of_collections} - display the no of Collections'),
                value: woo_cl_add_to_collection_text,
                onChange: function (response_woo_cl_add_to_collection_text) {
                  props.setAttributes({ woo_cl_add_to_collection_text: response_woo_cl_add_to_collection_text })
                }
              }),
              // Select button type
              el(SelectControl, {
                label: i18n.__('Button / Link Type'),
                help: i18n.__('Here you can select a add to Collection button type.'),
                value: woo_cl_add_to_collection_type,
                options: [
                  { label: i18n.__('Default'), value: 'default' },
                  { label: i18n.__('Button'), value: 'button' },
                  { label: i18n.__('Link'), value: 'link' },
                ],
                onChange: function (response_woo_cl_add_to_collection_type) {
                  props.setAttributes({ woo_cl_add_to_collection_type: response_woo_cl_add_to_collection_type })
                }
              }),
              // Select icon
              el(SelectControl, {
                label: i18n.__('Icon'),
                help: i18n.__('The icon to show next to the add to Collection links.'),
                value: cl_add_to_collection_link_icon,
                options: [
                  { label: i18n.__('None'), value: "" },
                  { label: i18n.__('Star'), value: "fa fa-star" },
                  { label: i18n.__('Present'), value: "fa fa-gift" },
                  { label: i18n.__('Add'), value: "fa fa-plus" },
                  { label: i18n.__('Bookmark'), value: "fa fa-bookmark" },
                  { label: i18n.__('Heart'), value: "fa fa-heart" },
                ],
                onChange: function (response_cl_add_to_collection_link_icon) {
                  props.setAttributes({ cl_add_to_collection_link_icon: response_cl_add_to_collection_link_icon })
                }
              }),
            )
          ),
          el(ServerSideRender, {
            block: 'wpweb/woo-collections-block',
            attributes: attributes,
          }),
        ]
      } else if (woo_cl_shortcodes == "woo_cl_featured_collections") {
        return [

          el(BlockControls, { key: 'controls' }, // Display controls when the block is clicked on.
          ),
          el(InspectorControls, { key: 'inspector' }, // Display the block options in the inspector panel.
            el(components.PanelBody, {
              title: i18n.__('WooCommerce Collections Settings'),
              className: 'wp-block-settings',
              initialOpen: true
            },

              // Select A Shortcode
              el(SelectControl, {
                label: i18n.__('Select A Shortcode'),
                help: i18n.__('Add A WooCommerce Collections Shortcode.'),
                value: woo_cl_shortcodes,
                options: [
                  { label: i18n.__('Add to Collection'), value: 'woo_cl_add_to_collection' },
                  { label: i18n.__('Featured Collections'), value: 'woo_cl_featured_collections' },
                  { label: i18n.__('My Collections'), value: 'woo_cl_my_collections' },
                ],
                onChange: function (response_woo_cl_shortcodes) {
                  props.setAttributes({ woo_cl_shortcodes: response_woo_cl_shortcodes })
                }
            }),

            el(TextControl, {
              type: 'text',
              label: i18n.__('Featured Collection Title'),
              help: i18n.__('Enter Featured Collection Title.'),
              value: woo_cl_featured_colls_title,
              onChange: function (response_woo_cl_featured_colls_title) {
                props.setAttributes({ woo_cl_featured_colls_title: response_woo_cl_featured_colls_title })
              }
            }),
            el(TextControl, {
              type: 'text',
              label: i18n.__('Number of Collections'),
              help: i18n.__('Enter a number of Collection you want to display.'),
              value: woo_cl_no_of_coll,
              onChange: function (response_woo_cl_no_of_coll) {
                props.setAttributes({ woo_cl_no_of_coll: response_woo_cl_no_of_coll })
              }
            }),
            // 
            el(CheckboxControl, {
              label: i18n.__('Show Private'),
              help: i18n.__('Check this box if you want to display private Collections.'),
              checked: woo_cl_show_private,
              onChange: function (response_woo_cl_show_private) {
                props.setAttributes({ woo_cl_show_private: response_woo_cl_show_private })
              }
            }),
            )
          ),
          el(ServerSideRender, {
            block: 'wpweb/woo-collections-block',
            attributes: attributes,
          }),
        ]
      } else if (woo_cl_shortcodes == "woo_cl_my_collections") {
        return [

          el(BlockControls, { key: 'controls' }, // Display controls when the block is clicked on.
          ),
          el(InspectorControls, { key: 'inspector' }, // Display the block options in the inspector panel.
            el(components.PanelBody, {
              title: i18n.__('WooCommerce Collections Settings'),
              className: 'wp-block-settings',
              initialOpen: true
            },

              // Select A Shortcode
              el(SelectControl, {
                label: i18n.__('Select A Shortcode'),
                help: i18n.__('Add A WooCommerce Collections Shortcode.'),
                value: woo_cl_shortcodes,
                options: [
                  { label: i18n.__('Add to Collection'), value: 'woo_cl_add_to_collection' },
                  { label: i18n.__('Featured Collections'), value: 'woo_cl_featured_collections' },
                  { label: i18n.__('My Collections'), value: 'woo_cl_my_collections' },
                ],
                onChange: function (response_woo_cl_shortcodes) {
                  props.setAttributes({ woo_cl_shortcodes: response_woo_cl_shortcodes })
                }
            }),
            el(TextControl, {
              type: 'text',
              label: i18n.__('My Collections Title'),
              help: i18n.__('Enter My Collection Title.'),
              value: woo_cl_my_colls_title,
              onChange: function (response_woo_cl_my_colls_title) {
                props.setAttributes({ woo_cl_my_colls_title: response_woo_cl_my_colls_title })
              }
            }),
            // 
            el(CheckboxControl, {
              label: i18n.__('Show Collections Count'),
              help: i18n.__('Check this box if you want to display total number of Collections.'),
              checked: woo_cl_show_all_colls_count,
              onChange: function (response_woo_cl_show_all_colls_count) {
                props.setAttributes({ woo_cl_show_all_colls_count: response_woo_cl_show_all_colls_count })
              }
            }),
            el(CheckboxControl, {
              label: i18n.__('Show See All Collections Link'),
              help: i18n.__('Check this box if you want to display link for See All Collections.'),
              checked: woo_cl_show_all_colls_link,
              onChange: function (response_woo_cl_show_all_colls_link) {
                props.setAttributes({ woo_cl_show_all_colls_link: response_woo_cl_show_all_colls_link })
              }
            }),

            )
          ),
          el(ServerSideRender, {
            block: 'wpweb/woo-collections-block',
            attributes: attributes,
          }),
        ]
      }
    },
    save: function (props) {
      return null;
    },
  });
}(
  window.wp.blocks,
  window.wp.editor,
  window.wp.components,
  window.wp.i18n,
  window.wp.element
));
